==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Input.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { InputBase } from "./InputBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
/**
 * @hidden
 */
export let Input = /*@__PURE__*/ (() => {
    class Input extends InputBase {
        constructor() {
            super(...arguments);
            this.change = null;
        }
        changeChanged() {
            if (this.change != null) {
                this.f.q("change", (a) => this.change(this, ComponentValueChangedEventArgs.a(a)));
            }
            else {
                this.f.t("change");
            }
        }
        get am() {
            let ret_ = this.f.m("value");
            return ret_;
        }
        set am(a) {
            let value_ = a;
            this.f.u("value", value_);
        }
        get ab() {
            let ret_ = this.f.m("type");
            ret_ = enumGetBox(InputType_$type, EnumUtil.getEnumValue(InputType_$type, this.f.f(InputType_$type, ret_)));
            return EnumUtil.getEnumValue(InputType_$type, ret_);
        }
        set ab(a) {
            let value_ = enumGetBox(InputType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("type", value_);
        }
        get aa() {
            let ret_ = this.f.m("inputmode");
            ret_ = enumGetBox(InputInputmode_$type, EnumUtil.getEnumValue(InputInputmode_$type, this.f.f(InputInputmode_$type, ret_)));
            return EnumUtil.getEnumValue(InputInputmode_$type, ret_);
        }
        set aa(a) {
            let value_ = enumGetBox(InputInputmode_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("inputmode", value_);
        }
        get al() {
            let ret_ = this.f.m("pattern");
            return ret_;
        }
        set al(a) {
            let value_ = a;
            this.f.u("pattern", value_);
        }
        get ad() {
            let ret_ = this.f.m("invalid");
            return ret_;
        }
        set ad(a) {
            let value_ = a;
            this.f.u("invalid", value_);
        }
        get af() {
            let ret_ = this.f.m("minlength");
            return ret_;
        }
        set af(a) {
            let value_ = a;
            this.f.u("minlength", value_);
        }
        get ae() {
            let ret_ = this.f.m("maxlength");
            return ret_;
        }
        set ae(a) {
            let value_ = a;
            this.f.u("maxlength", value_);
        }
        get ak() {
            let ret_ = this.f.m("min");
            return ret_;
        }
        set ak(a) {
            let value_ = a;
            this.f.u("min", value_);
        }
        get aj() {
            let ret_ = this.f.m("max");
            return ret_;
        }
        set aj(a) {
            let value_ = a;
            this.f.u("max", value_);
        }
        get ag() {
            let ret_ = this.f.m("step");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.f.u("step", value_);
        }
        get ac() {
            let ret_ = this.f.m("autofocus");
            return ret_;
        }
        set ac(a) {
            let value_ = a;
            this.f.u("autofocus", value_);
        }
        get ai() {
            let ret_ = this.f.m("autocomplete");
            return ret_;
        }
        set ai(a) {
            let value_ = a;
            this.f.u("autocomplete", value_);
        }
        get ah() {
            let ret_ = this.f.m("tabIndex");
            return ret_;
        }
        set ah(a) {
            let value_ = a;
            this.f.u("tabIndex", value_);
        }
        ap() {
            this.nativeElement.reportValidity();
        }
        ao() {
            this.nativeElement.checkValidity();
        }
        ar(a) {
            this.nativeElement.setCustomValidity(this.f.h(a));
        }
        aq() {
            this.nativeElement.select();
        }
        at(a) {
            this.nativeElement.stepUp(this.f.h(a));
        }
        as(a) {
            this.nativeElement.stepDown(this.f.h(a));
        }
    }
    Input.$t = /*@__PURE__*/ markType(Input, 'Input', InputBase.$);
    return Input;
})();

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/Input.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { InputBase } from "./InputBase";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
/**
 * @hidden
 */
export let Input = /*@__PURE__*/ (() => {
    class Input extends InputBase {
        constructor() {
            super(...arguments);
            this.change = null;
        }
        changeChanged() {
            if (this.change != null) {
                this.f.r("change", (a) => this.change(this, ComponentValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("change");
            }
        }
        get an() {
            let ret_ = this.f.n("value");
            return ret_;
        }
        set an(a) {
            let value_ = a;
            this.f.v("value", value_);
        }
        get ae() {
            let ret_ = this.f.n("type");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(InputType_$type, EnumUtil.getEnumValue(InputType_$type, this.f.f(InputType_$type, ret_)));
            return EnumUtil.getEnumValue(InputType_$type, ret_);
        }
        set ae(a) {
            let value_ = enumGetBox(InputType_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("type", value_);
        }
        get ad() {
            let ret_ = this.f.n("inputmode");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(InputInputmode_$type, EnumUtil.getEnumValue(InputInputmode_$type, this.f.f(InputInputmode_$type, ret_)));
            return EnumUtil.getEnumValue(InputInputmode_$type, ret_);
        }
        set ad(a) {
            let value_ = enumGetBox(InputInputmode_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("inputmode", value_);
        }
        get am() {
            let ret_ = this.f.n("pattern");
            return ret_;
        }
        set am(a) {
            let value_ = a;
            this.f.v("pattern", value_);
        }
        get ah() {
            let ret_ = this.f.n("minLength");
            return ret_;
        }
        set ah(a) {
            let value_ = a;
            this.f.v("minLength", value_);
        }
        get ag() {
            let ret_ = this.f.n("maxLength");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.f.v("maxLength", value_);
        }
        get al() {
            let ret_ = this.f.n("min");
            return ret_;
        }
        set al(a) {
            let value_ = a;
            this.f.v("min", value_);
        }
        get ak() {
            let ret_ = this.f.n("max");
            return ret_;
        }
        set ak(a) {
            let value_ = a;
            this.f.v("max", value_);
        }
        get ai() {
            let ret_ = this.f.n("step");
            return ret_;
        }
        set ai(a) {
            let value_ = a;
            this.f.v("step", value_);
        }
        get af() {
            let ret_ = this.f.n("autofocus");
            return ret_;
        }
        set af(a) {
            let value_ = a;
            this.f.v("autofocus", value_);
        }
        get aj() {
            let ret_ = this.f.n("autocomplete");
            return ret_;
        }
        set aj(a) {
            let value_ = a;
            this.f.v("autocomplete", value_);
        }
        ap() {
            this.nativeElement.select();
        }
        ar(a = -1) {
            this.nativeElement.stepUp(this.f.i(a));
        }
        aq(a = -1) {
            this.nativeElement.stepDown(this.f.i(a));
        }
    }
    Input.$t = /*@__PURE__*/ markType(Input, 'Input', InputBase.$);
    return Input;
})();
